#!/bin/bash
set -e

# On Ubuntu 20.04, these packages are required:
# - build-essential
# - mingw-w64
# - mingw-w64-tools
# - libz-mingw-w64-dev
# - automake
# - libtool
# - nasm

# TODO: instructions on how to patch pkg-config on Ubuntu 20.04 to fix it for mingw32

# Intel Media SDK Build steps:
# - git clone https://github.com/lu-zero/mfx_dispatch.git && cd mfx_dispatch
# - autoreconf -i
# - ./configure --host=i686-w64-mingw32
# - make -j$(nproc)
# - sudo make install

# nv-codec-headers v8.1
# - git clone https://git.videolan.org/git/ffmpeg/nv-codec-headers.git --branch sdk/8.1 && nv-codec-headers
# - make
# - sudo make install

# AMF
# - git clone https://github.com/GPUOpen-LibrariesAndSDKs/AMF.git && cd AMF
# - sudo mkdir -p /usr/local/include/AMF
# - sudo cp -r amf/public/include/. /usr/local/include/AMF

# Set the pkgconfig specifically for nvidia, intel, and amd header files
export PKG_CONFIG_PATH="/usr/local/lib/pkgconfig"

cd $BASEDIR

./configure --pkg-config-flags="--static" --arch=x86 --target-os=mingw32 --cross-prefix=i686-w64-mingw32- --disable-everything --enable-zlib \
--enable-small --enable-ffmpeg --disable-ffplay --disable-ffprobe --enable-encoder=aac_mf,mjpeg,wrapped_avframe,h264_nvenc,h264_qsv,h264_amf --enable-decoder=h264_mf,aac_mf,png,mjpeg,gif,bmp,rawvideo --enable-indev=lavfi \
--enable-protocol=file,pipe --enable-demuxer=mov,ffmetadata,image2,gif --enable-muxer=mp4,image2,ffmetadata,null --enable-filter=aresample,color,scale,showinfo,setpts,asetpts,concat,zoompan,setsar,overlay,setrange --disable-dxva2 \
--disable-d3d11va --disable-schannel --disable-xlib --enable-nvenc --enable-nvdec --enable-amf --enable-libmfx --extra-cflags="-I/usr/local/include" --extra-cxxflags="-I/usr/local/include" --enable-mediafoundation \
--extra-ldflags="-static -static-libgcc -static-libstdc++"

make clean
make -j$(nproc)
rm -f ffmpeg.zip ffmpeg-src.tar.gz
zip ffmpeg.zip ffmpeg.exe
git archive -o ffmpeg-src.tar.gz HEAD . ":(exclude)Jenkinsfile" ":(exclude)jenkinsContainerBuild.sh"
